downloadModel method
Triggers the proofreading model download (if one is needed) and streams progress updates until it completes or fails.
On iOS, Apple Intelligence must be enabled by the person in Settings — there's nothing for the app to trigger, so this immediately completes.
Implementation
Stream<EdgeGenAIDownloadProgress> downloadModel() {
return EdgeGenAIPlatform.instance.downloadModel(
EdgeGenAIFeature.proofreading,
);
}