onCall property

Future<String> Function(Map<String, Object?> arguments) onCall
final

Runs the tool with the arguments the model provided (decoded from JSON) and returns the result text the model continues generating with.

Implementation

final Future<String> Function(Map<String, Object?> arguments) onCall;