parameters property
The parameters the model should pass when calling the tool.
Implementation
final List<EdgeGenAIToolParameter> parameters;
The parameters the model should pass when calling the tool.
final List<EdgeGenAIToolParameter> parameters;