EdgeGenAIProofreader class
The on-device proofreading feature: fixes grammar, spelling, and punctuation without changing the text's meaning.
Backed by ML Kit GenAI's Proofreading API on Android and by a task-specific Foundation Models prompt on iOS.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkAvailability(
) → Future< EdgeGenAIAvailability> - Checks whether the on-device proofreading feature is available.
-
downloadModel(
) → Stream< EdgeGenAIDownloadProgress> - Triggers the proofreading model download (if one is needed) and streams progress updates until it completes or fails.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
proofread(
String text) → Future< String> -
Proofreads
textand returns the corrected text. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited