onCall property
Runs the tool with the arguments the model provided (decoded from
JSON) and returns the result text the model continues generating with.
Implementation
final Future<String> Function(Map<String, Object?> arguments) onCall;
Runs the tool with the arguments the model provided (decoded from
JSON) and returns the result text the model continues generating with.
final Future<String> Function(Map<String, Object?> arguments) onCall;